==> flutter95-0.0.5.tar.gz: lib/src/toolbar95.dart <==
import 'package:flutter/rendering.dart';
import 'package:flutter/widgets.dart';
import 'package:flutter95/flutter95.dart';

class Toolbar95 extends StatelessWidget {
  Toolbar95({
    this.actions,
    Key key,
  }) : super(key: key);

  final List<Item95> actions;

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: const EdgeInsets.symmetric(horizontal: 4.0, vertical: 2.0),
      child: Row(
        children: actions,
      ),
    );
  }
}

class Item95 extends StatefulWidget {
  const Item95({
    @required this.label,
    this.onTap,
    Key key,
  }) : super(key: key);

  final String label;

  final Function() onTap;

  @override
  _Item95State createState() => _Item95State();
}

class _Item95State extends State<Item95> {
  bool _tapped = false;

  @override
  Widget build(BuildContext context) {
    return ConstrainedBox(
      constraints: BoxConstraints(
        maxHeight: 24,
        minWidth: 48,
      ),
      child: GestureDetector(
        onTap: widget.onTap,
        onTapDown: (details) => setState(() {
          if (widget.onTap != null) {
            _tapped = true;
          }
        }),
        onTapUp: (details) => setState(() {
          _tapped = false;
        }),
        onTapCancel: () => setState(() => _tapped = false),
        child: Container(
          decoration: _tapped
              ? Flutter95.pressedDecorationOutside
              : Flutter95.invisibleBorder,
          child: Container(
            decoration: _tapped
                ? Flutter95.pressedDecoration
                : Flutter95.invisibleBorder,
            padding: _tapped
                ? const EdgeInsets.only(top: 1.0, left: 1.0)
                : const EdgeInsets.all(0.0),
            child: Center(
              child: Text(
                widget.label,
                style: widget.onTap != null
                    ? Flutter95.textStyle
                    : Flutter95.disabledTextStyle,
              ),
            ),
          ),
        ),
      ),
    );
  }
}

==> flutter95-0.0.6.tar.gz: lib/src/toolbar95.dart <==
import 'package:flutter/rendering.dart';
import 'package:flutter/widgets.dart';
import 'package:flutter95/flutter95.dart';

class Toolbar95 extends StatelessWidget {
  Toolbar95({
    this.actions,
    Key key,
  }) : super(key: key);

  final List<Item95> actions;

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: const EdgeInsets.symmetric(horizontal: 4.0, vertical: 2.0),
      child: Row(
        children: actions,
      ),
    );
  }
}

class Item95 extends StatefulWidget {
  const Item95({
    @required this.label,
    this.onTap,
    this.menu,
    Key key,
  })  : assert(!(menu != null && onTap != null)),
        super(key: key);

  final String label;

  final List<MenuItem95<Object>> menu;

  final Function(BuildContext) onTap;

  @override
  _Item95State createState() => _Item95State();
}

class _Item95State extends State<Item95> {
  bool _tapped = false;

  @override
  Widget build(BuildContext context) {
    return ConstrainedBox(
      constraints: BoxConstraints(
        maxHeight: 24,
        minWidth: 48,
      ),
      child: GestureDetector(
        onTap: () => _onTap(context),
        onTapDown: (details) => setState(() {
          if (_enabled() || widget.menu != null) {
            _tapped = true;
          }
        }),
        onTapUp: (details) => setState(() {
          _tapped = false;
        }),
        onTapCancel: () => setState(() => _tapped = false),
        child: Container(
          decoration: _tapped
              ? Flutter95.pressedDecorationOutside
              : Flutter95.invisibleBorder,
          child: Container(
            decoration: _tapped
                ? Flutter95.pressedDecoration
                : Flutter95.invisibleBorder,
            padding: _tapped
                ? const EdgeInsets.only(top: 1.0, left: 1.0)
                : const EdgeInsets.all(0.0),
            child: Center(
              child: Text(
                widget.label,
                style: _enabled()
                    ? Flutter95.textStyle
                    : Flutter95.disabledTextStyle,
              ),
            ),
          ),
        ),
      ),
    );
  }

  bool _enabled() {
    return widget.onTap != null || widget.menu != null;
  }

  _onTap(BuildContext context) {
    if (widget.menu != null) {
//      showMenu95(context, context.rect.shift(Offset(0, 24)), widget.menu);
    } else if (_enabled()) {
      return widget.onTap(context);
    }
  }
}
